@@ -3,7 +3,7 @@
 use x86_64::structures::idt::{InterruptDescriptorTable, InterruptStackFrame};
 use lazy_static::lazy_static;
 use crate::{gdt, print, println};
-use crate::libcore::dev::drivers::pic8259::ChainPIC;
+use crate::libcore::{dev::drivers::pic8259::ChainPIC, task::kbd};
 use spin;
 
 pub const PIC_1_OFFSET: u8 = 32;
@@ -80,7 +80,7 @@ extern "x86-interrupt" fn keyboard_interrupt_handler(_stackframe: InterruptStack
 		port.read()
 	};
 
-	crate::task::kbd::add_scancode(scancode);
+	crate::libcore::task::kbd::add_scancode(scancode);
 
 	unsafe
 	{
