@@ -18,7 +18,12 @@ lazy_static!
 pub fn _print(args: ::core::fmt::Arguments)
 {
 	use core::fmt::Write;
+	use x86_64::instructions::interrupts;
+
+	interrupts::without_interrupts(||
+	{
 		SER1.lock().write_fmt(args).expect("[ERR] FAILED TO PRINT TO SERIAL");
+	});
 }
 
 #[macro_export]
